import React, { useState, useEffect } from 'react';
import '../styles/retro.css';

function Contact() {
  const [formData, setFormData] = useState({
    name: '',
    email: '',
    subject: '異次元案件について',
    message: ''
  });
  const [isSubmitting, setIsSubmitting] = useState(false);
  const [submitMessage, setSubmitMessage] = useState('');
  const [charCount, setCharCount] = useState(0);

  useEffect(() => {
    // 文字カウントの更新
    setCharCount(formData.message.length);
  }, [formData.message]);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData(prev => ({
      ...prev,
      [name]: value
    }));
  };

  const handleSubmit = async (e) => {
    e.preventDefault();
    setIsSubmitting(true);
    
    // 送信シミュレーション
    await new Promise(resolve => setTimeout(resolve, 2000));
    
    setSubmitMessage('🌟 異次元空間経由で送信されました！ 🌟');
    setIsSubmitting(false);
    
    // フォームリセット
    setFormData({
      name: '',
      email: '',
      subject: '異次元案件について',
      message: ''
    });
  };

  return (
    <div className="win95-box">
      <h1 className="glitter">お問い合わせ</h1>
      <div className="marquee-container">
        <marquee>⚡ 異次元からのお問い合わせもお待ちしております ⚡</marquee>
      </div>

      <form onSubmit={handleSubmit} className="contact-form">
        <div className="form-group">
          <label htmlFor="name">お名前:</label>
          <input
            type="text"
            id="name"
            name="name"
            value={formData.name}
            onChange={handleChange}
            required
            className="win95-input"
          />
        </div>

        <div className="form-group">
          <label htmlFor="email">メールアドレス:</label>
          <input
            type="email"
            id="email"
            name="email"
            value={formData.email}
            onChange={handleChange}
            required
            className="win95-input"
          />
        </div>

        <div className="form-group">
          <label htmlFor="subject">件名:</label>
          <select
            id="subject"
            name="subject"
            value={formData.subject}
            onChange={handleChange}
            className="win95-select"
          >
            <option value="異次元案件について">異次元案件について</option>
            <option value="採用について">採用について</option>
            <option value="タイムスリップ体験">タイムスリップ体験</option>
            <option value="その他">その他</option>
          </select>
        </div>

        <div className="form-group">
          <label htmlFor="message">メッセージ:</label>
          <textarea
            id="message"
            name="message"
            value={formData.message}
            onChange={handleChange}
            required
            className="win95-textarea"
            rows="5"
          />
          <div className="char-count">
            残り{1000 - charCount}文字
          </div>
        </div>

        <button 
          type="submit" 
          className="win95-button"
          disabled={isSubmitting}
        >
          {isSubmitting ? '送信中...' : '送信'}
        </button>

        {submitMessage && (
          <div className="submit-message blink">
            {submitMessage}
          </div>
        )}
      </form>
    </div>
  );
}

export default Contact; 