import React, { useRef, useState } from "react";
import BlinkingText from "../components/BlinkingText";
import "../styles/retro.css";
import MidiPlayer from "../components/MidiPlayer";
import kawaiiFrog from "../assets/29081.gif"; // かわいいカエルのGIF
import companyVideo from "../assets/107276_640x360.mp4"; // 動画をインポート

const GlitteringLogo = () => {
  return (
    <div className="win95-box" style={{ textAlign: 'center' }}>
      <img 
        src="https://via.placeholder.com/150x150" 
        alt="ウィナスロゴ"
        className="glitter"
        style={{ 
          border: '2px solid #000',
          padding: '10px',
          backgroundColor: '#fff'
        }} 
      />
      <h1 className="glitter rainbow-text">株式会社 ピーナッツ</h1>
      <div className="visitor-counter">
        あなたは{Math.floor(Math.random() * 100000)}人目の訪問者です！
      </div>
    </div>
  );
};

function Home() {
  const videoRef = useRef(null);
  const [isPlaying, setIsPlaying] = useState(false);

  const handleVideoClick = () => {
    if (videoRef.current) {
      if (isPlaying) {
        videoRef.current.pause();
      } else {
        videoRef.current.play();
      }
      setIsPlaying(!isPlaying);
    }
  };

  return (
    <div className="win95-box">
      <marquee className="news-ticker" behavior="scroll" direction="left">
        ★重要なお知らせ★ 当社は24時間365日、異次元空間でビジネスを展開しています！
      </marquee>
      
      <GlitteringLogo />
      <BlinkingText text="✨ようこそ、ウィナスの採用サイトへ！✨" />
      <MidiPlayer />

      <div className="win95-box news-section">
        <h2 className="glitter">
          最新ニュース
          <img src={kawaiiFrog} alt="かわいいカエル" className="mascot-gif" />
        </h2>
        <ul className="news-list">
          <li>
            <span className="news-date">2024.03.14</span>
            社内マスコットキャラクターが決定しました！
          </li>
          <li>
            <span className="news-date">2024.03.01</span>
            社員旅行で第五次元へ行ってきました
          </li>
        </ul>
      </div>

      <div className="win95-box">
        <h2 className="glitter">事業内容</h2>
        <div className="business-content">
          <ul className="service-list">
            <li>💫 異次元空間プロデュース</li>
            <li>🌈 量子もつれビジネスコンサルティング</li>
            <li>🎮 レトロゲーム風システム開発</li>
            <li>🌟 パラレルワールドツアー企画</li>
          </ul>
          <img src={kawaiiFrog} alt="かわいいカエル" className="mascot-gif-large" />
        </div>
      </div>

      <div className="win95-box">
        <h2 className="glitter">アクセスカウンター</h2>
        <div className="counter-display">
          <span className="counter-digit">0</span>
          <span className="counter-digit">0</span>
          <span className="counter-digit">4</span>
          <span className="counter-digit">2</span>
          <span className="counter-digit">0</span>
        </div>
      </div>

      <div className="win95-box video-section">
        <h2 className="glitter">
          会社紹介ムービー
          <img src={kawaiiFrog} alt="かわいいカエル" className="mascot-gif" />
        </h2>
        <div className="video-container">
          <video
            ref={videoRef}
            onClick={handleVideoClick}
            className="company-video"
          >
            <source src={companyVideo} type="video/mp4" />
            お使いのブラウザは動画再生に対応していません。
          </video>
          <button 
            className="win95-button video-control"
            onClick={handleVideoClick}
          >
            {isPlaying ? '⏸️ 一時停止' : '▶️ 再生'}
          </button>
          <div className="video-note">
            ※ クリックして{isPlaying ? '一時停止' : '再生'}
          </div>
        </div>
      </div>

      <div className="best-viewed">
        このサイトは Internet Explorer 4.0 で最適に表示されます
        <br />
        推奨解像度：640×480
      </div>
    </div>
  );
}

export default Home;